@@ -628,7 +628,7 @@ def genpdf(maadstoken,maads_rest_url,pkey,urltomaadsserver,savetofolder,username
     except Exception as e:  
       return "ERROR: Retrieving PDF: %s" % e 
 
-def optimize (maadstoken,maads_rest_url,algo1,ismin=1,objeq='1,1,1',a1cons=1,forceupdate=0,algo2='',algo3='',a2cons=1,a3cons=1,iters=100,step=4,perc='min_0_max_0'):
+def optimize (maadstoken,maads_rest_url,algo1,ismin=1,objeq='1,1,1',a1cons=1,boundslimits='none',forceupdate=0,algo2='',algo3='',a2cons=1,a3cons=1,iters=100,step=4,perc='min_0_max_0'):
 
     if len(algo1)<=0:
         return "ERROR: Algo 1 must be specified"
@@ -639,7 +639,7 @@ def optimize (maadstoken,maads_rest_url,algo1,ismin=1,objeq='1,1,1',a1cons=1,for
         'algo2': algo2,
         'algo3': algo3,
         'forceupdate': forceupdate,
-             
+        'boundslimits': boundslimits,     
         'maadstoken':maadstoken,     
         'a1cons':a1cons,
         'a2cons':a2cons,
